# -*- coding: utf-8 -*-
from django.apps import AppConfig


class AccountsConfig(AppConfig):
    name = 'impersonate'
    default_auto_field = 'django.db.models.AutoField'

    def ready(self):
        from . import signals



# -*- coding: utf-8 -*-
from django.urls import path

from . import views

urlpatterns = [
    path('stop/', views.stop_impersonate, name='impersonate-stop'),
    path(
        'list/',
        views.list_users,
        {'template': 'impersonate/list_users.html'},
        name='impersonate-list',
    ),
    path(
        'search/',
        views.search_users,
        {'template': 'impersonate/search_users.html'},
        name='impersonate-search',
    ),
    path('<path:uid>/', views.impersonate, name='impersonate-start'),
]



# compatibility module for handling Django upgrade namespace changes
try:
    from django.urls import reverse
except ImportError:
    from django.core.urlresolvers import reverse

__all__ = ["reverse"]
